pywr.recorders.StorageDurationCurveRecorder — Pywr 0.5dev documentation

# pywr.recorders.StorageDurationCurveRecorder

class `pywr.recorders.` `StorageDurationCurveRecorder`

  This recorder calculates a storage duration curve for each scenario.

  Parameters: | model : pywr.core.Model node : pywr.core.AbstractStorage The node to record percentiles : array The percentiles to use in the calculation of the flow duration curve. Values must be in the range 0-100. agg_func: str, optional function used for aggregating the FDC across percentiles. Numpy style functions that support an axis argument are supported. sdc_agg_func: str, optional optional different function for aggregating across scenarios.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `aggregated_value` |
  `before` |
  `finish` |
  `load` |
  `register` |
  `reset` |
  `setup` |
  `to_dataframe` | Return a pandas.DataFrame of the recorder data
  `unregister` |
  `values` | Compute a value for each scenario using temporal_agg_func.

  Attributes

  `agg_func` |
  `children` |
  `comment` |
  `data` |
  `epsilon` |
  `ignore_nan` |
  `is_constraint` |
  `is_objective` |
  `model` |
  `name` |
  `node` |
  `parents` |
  `sdc` |
  `temporal_agg_func` |